VectorMemory

Struct VectorMemory 

pub struct VectorMemory<E = SimpleEmbedder, S = InMemoryVectorStore> { /* private fields */ }
Memory backend that combines recent history with semantic retrieval.

Implementations

Source

impl VectorMemory<SimpleEmbedder, InMemoryVectorStore>

pub fn new() -> Self

Creates a vector memory with built-in components.

Source

impl<E, S> VectorMemory<E, S>
where E: Embedder, S: VectorStore,

pub fn with_components(embedder: Arc<E>, store: Arc<S>) -> Self

Creates a vector memory with custom embedder and store.